Crate rocket_mongo_file_center_download_response

Crate rocket_mongo_file_center_download_response 

File Center Download Response on MongoDB for Rocket Framework

This crate provides a response struct used for client downloading from the File Center on MongoDB.

See examples.

Re-exports

pub extern crate mongo_file_center;

Structs

FileCenterDownloadResponse
The response struct used for client downloading from the File Center on MongoDB.