File Center Download Response on MongoDB for Rocket Framework
This crate provides a response struct used for client downloading from the File Center on MongoDB.
See examples.
Re-exports
pub extern crate mongo_file_center;
Structs
- File
Center Download Response - The response struct used for client downloading from the File Center on MongoDB.